==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/enums/WorkflowProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The provisioning state.
 */
public enum class WorkflowProvisioningState(
    public val javaValue: com.pulumi.azurenative.logic.enums.WorkflowProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.logic.enums.WorkflowProvisioningState> {
    NotSpecified(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.NotSpecified),
    Accepted(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Accepted),
    Running(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Running),
    Ready(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Ready),
    Creating(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Creating),
    Created(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Created),
    Deleting(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Deleting),
    Deleted(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Deleted),
    Canceled(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Canceled),
    Failed(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Failed),
    Succeeded(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Succeeded),
    Moving(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Moving),
    Updating(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Updating),
    Registering(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Registering),
    Registered(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Registered),
    Unregistering(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Unregistering),
    Unregistered(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Unregistered),
    Completed(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Completed),
    Renewing(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Renewing),
    Pending(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Pending),
    Waiting(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Waiting),
    InProgress(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.InProgress),
    ;

    override fun toJava(): com.pulumi.azurenative.logic.enums.WorkflowProvisioningState = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.enums.WorkflowProvisioningState):
            WorkflowProvisioningState =
            WorkflowProvisioningState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/logic/kotlin/enums/WorkflowProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The provisioning state.
 */
public enum class WorkflowProvisioningState(
    public val javaValue: com.pulumi.azurenative.logic.enums.WorkflowProvisioningState,
) : ConvertibleToJava<com.pulumi.azurenative.logic.enums.WorkflowProvisioningState> {
    NotSpecified(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.NotSpecified),
    Accepted(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Accepted),
    Running(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Running),
    Ready(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Ready),
    Creating(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Creating),
    Created(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Created),
    Deleting(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Deleting),
    Deleted(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Deleted),
    Canceled(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Canceled),
    Failed(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Failed),
    Succeeded(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Succeeded),
    Moving(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Moving),
    Updating(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Updating),
    Registering(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Registering),
    Registered(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Registered),
    Unregistering(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Unregistering),
    Unregistered(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Unregistered),
    Completed(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Completed),
    Renewing(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Renewing),
    Pending(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Pending),
    Waiting(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.Waiting),
    InProgress(com.pulumi.azurenative.logic.enums.WorkflowProvisioningState.InProgress),
    ;

    override fun toJava(): com.pulumi.azurenative.logic.enums.WorkflowProvisioningState = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.enums.WorkflowProvisioningState): WorkflowProvisioningState =
            WorkflowProvisioningState.values().first { it.javaValue == javaType }
    }
}
